@@ -29,7 +29,7 @@ except ImportError:
     import urllib2
     import urllib
 
-SDK_VERSION = '1.0.2'
+SDK_VERSION = '1.0.3'
 batch_consumer_lock = threading.RLock()
 
 try:
@@ -588,6 +588,7 @@ class ConsoleConsumer(object):
 class LoggingConsumer(object):
     """
     将数据使用 logging 库输出到指定路径，并默认按天切割
+    多进程输出log请使用ConcurrentLoggingConsumer
     log_name 为log存储的绝对路径+log名称，此路径与filebeat中的配置文件paths要一致
     如果只想日志存储到本地，不通过filebeat传递至后端，可不将日志路径添加在filebeat配置文件的paths中
     """
@@ -651,7 +652,7 @@ class ConcurrentLoggingConsumer(object):
         self._encoding = encoding
 
         filename = ConcurrentLoggingConsumer.construct_filename(self._log_name)
-        print(filename)
+        # print(filename)
         self._writer = ConcurrentLoggingConsumer.ConcurrentFileWriter(filename, encoding=self._encoding)
 
     def send(self, msg):
